==> LixM_SE_1.2_src.zip: src/org/lixm/core/common/XMLType.java <==
package org.lixm.core.common;

/**
 * <p>fʂ邽߂̒萔QłB</p>
 * 
 * <pre class="code">
 *      AbstractModel model = list.get(0);
 *
 *      if(model.matchType(XMLType.START_DOCUMENT)){
 *              System.out.println("wlkJn܂B");
 *      }
 * </pre>
 * 
 * @author tasogare
 * @version 1.7.0
 * @since 1.5
 * @see org.lixm.core.model.XMLModel#getXMLType()
 * @see org.lixm.core.model.AbstractModel#matchTypes(int)
 */
public final class XMLType {

    /**
     * wlk錾\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     * @since v15
     */
    public static final int XML_DECL        = 0;

    /**
     * vf\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int ELEMENT         = 1;

    /**
     * \܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int       ATTRIBUTE       = 2;

    /**
     * ̃Xg\܂B
     * {@link org.lixm.core.list.AttributesList AttributesList}
     * \̂ɗp܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     * @see org.lixm.core.list.AttributesList
     */
    public static final int ATTRIBUTES_LIST = 3;

    /**
     * wlk͂̊Jn\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int START_DOCUMENT  = 4;

    /**
     * wlk͂̏I\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int END_DOCUMENT    = 5;

    /**
     * Jn^O\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int START_TAG       = 6;

    /**
     * I^O\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int END_TAG         = 7;

    /**
     * bc`s`ZNVJnƂ\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int START_CDATA_SECT     = 8;

    /**
     * bc`s`ZNVIƂ\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int END_CDATA_SECT       = 9;

    /**
     * wlkɏo镶f[^\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int CDATA            = 10;

    /**
     * ߂\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int PI              = 11;

    /**
     * Rg\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int COMMENT         = 12;

    private XMLType(){
    }
}

==> LixM_SE_1.2.1_src.zip: src/org/lixm/core/common/XMLType.java <==
package org.lixm.core.common;

/**
 * <p>fʂ邽߂̒萔QłB</p>
 * 
 * <pre class="code">
 *      AbstractModel model = list.get(0);
 *
 *      if(model.matchType(XMLType.START_DOCUMENT)){
 *              System.out.println("wlkJn܂B");
 *      }
 * </pre>
 * 
 * @author tasogare
 * @version 1.7.1
 * @since 1.5
 * @see org.lixm.core.model.XMLModel#getXMLType()
 * @see org.lixm.core.model.AbstractModel#matchTypes(int)
 */
public final class XMLType {

    /**
     * wlk錾\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     * @since v15
     */
    public static final int XML_DECL        = 0;

    /**
     * vf\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int ELEMENT         = 1;

    /**
     * \܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int       ATTRIBUTE       = 2;

    /**
     * ̃Xg\܂B
     * {@link org.lixm.core.list.AttributesList AttributesList}
     * \̂ɗp܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     * @see org.lixm.core.list.AttributesList
     */
    public static final int ATTRIBUTES_LIST = 3;

    /**
     * wlk͂̊Jn\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int START_DOCUMENT  = 4;

    /**
     * wlk͂̏I\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int END_DOCUMENT    = 5;

    /**
     * Jn^O\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int START_TAG       = 6;

    /**
     * I^O\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int END_TAG         = 7;

    /**
     * bc`s`ZNVJnƂ\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int START_CDATA_SECT     = 8;

    /**
     * bc`s`ZNVIƂ\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int END_CDATA_SECT       = 9;

    /**
     * wlkɏo镶f[^\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int CHARACTERS            = 10;

    /**
     * ߂\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int PI              = 11;

    /**
     * Rg\܂B
     * @see org.lixm.core.model.XMLModel#getXMLType()
     */
    public static final int COMMENT         = 12;

    private XMLType(){
    }
}
